@@ -10,10 +10,13 @@ int main()
 {
     seqan3::sequence_file_input file{std::filesystem::current_path() / "my.fasta"};
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-variable"
 //![record_range]
 for (auto & record : file)
 {
     // do something with my record
 }
 //![record_range]
+#pragma GCC diagnostic pop
 }
