@@ -29,16 +29,15 @@
 #include <seqan3/alphabet/views/to_char.hpp>
 #include <seqan3/core/range/detail/misc.hpp>
 #include <seqan3/core/range/type_traits.hpp>
-#include <seqan3/io/detail/istreambuf_view.hpp>
 #include <seqan3/io/detail/misc.hpp>
-#include <seqan3/io/detail/take_line_view.hpp>
-#include <seqan3/io/detail/take_until_view.hpp>
-#include <seqan3/io/detail/take_view.hpp>
 #include <seqan3/io/structure_file/detail.hpp>
 #include <seqan3/io/structure_file/input_format_concept.hpp>
 #include <seqan3/io/structure_file/input_options.hpp>
 #include <seqan3/io/structure_file/output_format_concept.hpp>
 #include <seqan3/io/structure_file/output_options.hpp>
+#include <seqan3/io/views/detail/istreambuf_view.hpp>
+#include <seqan3/io/views/detail/take_line_view.hpp>
+#include <seqan3/io/views/detail/take_until_view.hpp>
 #include <seqan3/utility/char_operations/predicate.hpp>
 #include <seqan3/utility/detail/type_name_as_string.hpp>
 #include <seqan3/utility/views/to.hpp>
@@ -48,7 +47,7 @@ namespace seqan3
 /*!\brief       The Vienna format (dot bracket notation) for RNA sequences with secondary structure.
  * \implements  seqan3::structure_file_input_format
  * \implements  seqan3::structure_file_output_format
- * \ingroup     structure_file
+ * \ingroup     io_structure_file
  *
  * \details
  *
@@ -80,6 +79,8 @@ namespace seqan3
  * When reading the ID-line the identifier (`>`) and any blank characters before the actual ID are
  * stripped. Each field is read/written as a single line (except ENERGY, which goes right after the structure).
  * Numbers and spaces within the sequence are simply ignored, but not within the structure.
+ *
+ * \remark For a complete overview, take a look at \ref io_structure_file
  */
 class format_vienna
 {
