@@ -6,18 +6,20 @@
 // -----------------------------------------------------------------------------------------------------
 
 /*!\file
- * \brief Provides Char predicates for tokenization.
+ * \brief Meta-header for the \link utility_char_operations Utility / Builtin Character Operations submodule \endlink.
  * \author Rene Rahn <rene.rahn AT fu-berlin.de>
  * \author Hannes Hauswedell <hannes.hauswedell AT fu-berlin.de>
  */
 
+/*!\defgroup utility_char_operations Builtin Character Operations
+ * \brief Provides various operations on character types.
+ * \ingroup utility
+ * \see utility
+ */
+
 #pragma once
 
 #include <seqan3/utility/char_operations/predicate.hpp>
+#include <seqan3/utility/char_operations/predicate_detail.hpp>
 #include <seqan3/utility/char_operations/pretty_print.hpp>
 #include <seqan3/utility/char_operations/transform.hpp>
-
-/*!\defgroup char_operations Builtin Character Operations
- * \brief Provides various operations on character types.
- * \ingroup utility
- */
