@@ -20,12 +20,4 @@ int main()
     record_type my_record{};
     std::get<1>(my_record) = "the most important sequence in the database";            // access via index
     std::get<std::string>(my_record) = "the least important sequence in the database"; // access via type
-
-#ifdef SEQAN3_DEPRECATED_310
-    using seqan3::get;
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-    get<seqan3::field::seq>(my_record) = "ACGT"_dna4;                             // access via seqan3::field
-#pragma GCC diagnostic pop
-#endif //SEQAN3_DEPRECATED_310
 }
